## History

### 2015.02.26

0.2.0 release

- add Bag and OrderedBag
- rename to "aioutils"

### 2015.02.25

0.1.2 release

- fix some release problems

0.1.1 release

- basic group and pool implemenation


### 2015.02.23

ideas, prototypes
